@@ -4,6 +4,7 @@ sql_data <- function(value, row.names = FALSE, warn = FALSE) {
 
   value <- factor_to_string(value, warn = warn)
   value <- string_to_utf8(value)
+  value <- difftime_to_hms(value)
   value <- posixlt_to_posixct(value)
   value <- numeric_to_finite(value)
   value
@@ -30,6 +31,12 @@ string_to_utf8 <- function(value) {
   value
 }
 
+difftime_to_hms <- function(value) {
+  is_difftime <- vlapply(value, inherits, "difftime")
+  value[is_difftime] <- lapply(value[is_difftime], hms::as_hms)
+  value
+}
+
 posixlt_to_posixct <- function(value) {
   is_posixlt <- vlapply(value, inherits, "POSIXlt")
   value[is_posixlt] <- lapply(value[is_posixlt], as.POSIXct)
