@@ -2,16 +2,19 @@
 #define __RMARIADB_MARIA_RESULT_PREP__
 
 #include <boost/noncopyable.hpp>
-#include "DbConnection.h"
+#include <boost/shared_ptr.hpp>
+
 #include "MariaBinding.h"
-#include "DbResult.h"
 #include "MariaResultImpl.h"
 #include "MariaRow.h"
 #include "MariaTypes.h"
 #include "MariaUtils.h"
 
+class DbConnection;
+typedef boost::shared_ptr<DbConnection> DbConnectionPtr;
+
 class MariaResultPrep : boost::noncopyable, public MariaResultImpl {
-  DbResult* pRes_;
+  DbConnectionPtr pConn_;
 
   MYSQL_STMT* pStatement_;
   MYSQL_RES* pSpec_;
@@ -27,7 +30,7 @@ class MariaResultPrep : boost::noncopyable, public MariaResultImpl {
   MariaRow bindingOutput_;
 
 public:
-  MariaResultPrep(DbResult* res, bool is_statement = false);
+  MariaResultPrep(const DbConnectionPtr& pConn, bool is_statement = false);
   ~MariaResultPrep();
 
 public:
